@@ -1,11 +1,14 @@
 from email import header
 from pydoc import cli
+from tkinter import NS
+from async_timeout import asyncio
 from diskcache import Cache
 from threading import Lock
 
 from hamunafs.utils.redisutil import XRedis
 from hamunafs.utils.nsqmanager import MQManager
 from hamunafs.backends import BackendBase, backend_factory
+from hamunafs.conf import REDIS, NSQ
 
 
 import random
@@ -15,16 +18,27 @@ import time
 import uuid
 import json
 import httpx
+import nest_asyncio
+nest_asyncio.apply()
 
 class Client:
     @staticmethod
-    def get_client(host, redis_client: XRedis, mq_manager: MQManager, async_mq_mode=True, cache_path='../cache'):
+    def get_client(host, redis_client: XRedis, mq_manager: MQManager, async_mq_mode=True, cache_path='../cache', custom_async_loop=None):
         client = Client(host, redis_client, mq_manager, async_mq_mode)
         return client
     
-    def __init__(self, host, redis_client: XRedis, mq_manager: MQManager, async_mq_mode=True, cache_path='../cache') -> None:
+    def __init__(self, host, redis_client: XRedis, mq_manager: MQManager, async_mq_mode=True, cache_path='../cache', custom_async_loop=None) -> None:
         self.host = host
+        if redis_client is None:
+            redis_client = XRedis(REDIS['host'], REDIS['pass'], REDIS['port'], REDIS['db'])
         self.redis = redis_client
+        
+        # if mq_manager is None:
+        #     mq_manager = MQManager(NSQ['host'], NSQ['port'], async_mq=async_mq_mode)
+        #     if async_mq_mode:
+        #         if custom_async_loop is None:
+        #             custom_async_loop = asyncio.get_event_loop()
+        #         custom_async_loop.run_until_complete(mq_manager._init_async())
         self.mq = mq_manager
         self.async_mq = async_mq_mode
         self.lock = Lock()
@@ -90,7 +104,8 @@ class Client:
     def get_cache(self, key, toObj=True):
         data = self.index_cache.get(key)
         if data is None:
-            data = self.redis.get(key)
+            if self.redis is not None:
+                data = self.redis.get(key)
 
         if data is not None and toObj:
             data = json.loads(data)
@@ -204,5 +219,11 @@ class Client:
                 time.sleep(1)
                 
         return False, '获取失败'
+    
+    async def put_async(self, path, bucket, bucket_name, timeout=10, file_ttl=-1, mq=None):
+        pass
+    
+    async def get_async(self, path, url, force_copy=False, min_size=0, timeout=10):
+        pass
                     
                     
\ No newline at end of file
